@@ -118,13 +118,14 @@ def create_subplots(num_methrows, split, names=None):
 def qc_plots(meth_data, window):
     with open("qc_report_{}.html".format(window.string), 'w') as qc_report:
         qc_report.write(qc.num_sites_bar(meth_data))
-        if len([m for m in meth_data if m.data_type == "frequency"]) > 2:
+        if len([m for m in meth_data if m.data_type == "frequency"]) > 0:
             data = [m.table.rename({"methylated_frequency": m.name}, axis='columns')
                     for m in meth_data if m.data_type == "frequency"]
-            labels = [m.name for m in meth_data if m.data_type == "frequency"]
             full = data[0].join(data[1:]).dropna(how="any", axis="index")
-            qc_report.write(qc.pairwise_correlation_plot(full, labels))
-            qc_report.write(qc.pca(full, labels))
+            qc_report.write(qc.modified_fraction_histogram(full))
+        if len([m for m in meth_data if m.data_type == "frequency"]) > 2:
+            qc_report.write(qc.pairwise_correlation_plot(full))
+            qc_report.write(qc.pca(full))
             qc_report.write(qc.global_box(data))
         if len([m for m in meth_data if m.data_type in ["raw", "phased"]]) > 2:
             pass
